@@ -57,6 +57,106 @@
 
 #include "LALSimIMRSEOBNRROMUtilities.c"
 
+UNUSED static REAL8 XLALSimInspiralNRWaveformCheckFRef(
+  UNUSED LALH5File* file,
+  UNUSED REAL8 fRef
+)
+{
+  gsl_vector *omega_w_vec = NULL;
+  LALH5File *omega_group = NULL;
+  REAL8 min_fref, lowest_arr_fref;
+  if (fRef > 0)
+  {
+    /* This is the declared f_lower (using 1MSUN total mass) */
+    XLALH5FileQueryScalarAttributeValue(&min_fref, file, "f_lower_at_1MSUN");
+    /* This is the lowest f_lower in the Omega-vs-time array */
+    omega_group = XLALH5GroupOpen(file, "Omega-vs-time");
+    ReadHDF5RealVectorDataset(omega_group, "Y", &omega_w_vec);
+    XLALH5FileClose(omega_group);
+    lowest_arr_fref = gsl_vector_get(omega_w_vec, 0);
+    lowest_arr_fref = lowest_arr_fref / (LAL_MTSUN_SI * LAL_PI);
+    gsl_vector_free(omega_w_vec);
+    /* First, is fRef smaller than min_fref?
+     * Allow some float-precision slop */
+    if (fRef < 0.9999 * min_fref)
+    {
+      XLAL_ERROR(XLAL_EINVAL, "The supplied reference frequency is lower than the start frequency of the waveform. Start frequency (scaled by total mass) is %e and supplied fRef (scaled by total mass) is %e.\n", min_fref, fRef);
+    }
+    /* The Omega array may not quite extend to the minimum fRef, if that
+     * happens, fall back on the attribute values. */
+    if (fRef < lowest_arr_fref)
+    {
+      fRef = -1;
+    }
+  }
+  return fRef;
+}
+
+UNUSED static REAL8 XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(
+  UNUSED LALH5File* file,
+  UNUSED REAL8 fRef
+)
+{
+  #ifndef LAL_HDF5_ENABLED
+  XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
+  #else
+  /* NOTE: This is an internal function, it is expected that fRef is scaled
+   * to correspond to the fRef with a total mass of 1 solar mass */
+  LALH5File *curr_group = NULL;
+  gsl_vector *omega_t_vec = NULL;
+  gsl_vector *omega_w_vec = NULL;
+  gsl_interp_accel *acc;
+  gsl_spline *spline;
+  REAL8 ref_time;
+  curr_group = XLALH5GroupOpen(file, "Omega-vs-time");
+  ReadHDF5RealVectorDataset(curr_group, "X", &omega_t_vec);
+  ReadHDF5RealVectorDataset(curr_group, "Y", &omega_w_vec);
+  XLALH5FileClose(curr_group);
+  acc = gsl_interp_accel_alloc();
+  spline = gsl_spline_alloc(gsl_interp_cspline, omega_w_vec->size);
+  gsl_spline_init(spline, omega_w_vec->data, omega_t_vec->data,
+                  omega_t_vec->size);
+  ref_time = gsl_spline_eval(spline, fRef * (LAL_MTSUN_SI * LAL_PI), acc);
+  gsl_vector_free(omega_t_vec);
+  gsl_vector_free(omega_w_vec);
+  gsl_spline_free(spline);
+  gsl_interp_accel_free(acc);
+  return ref_time;
+  #endif
+}
+
+UNUSED static REAL8 XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint(
+  UNUSED LALH5File* file,                 /**< Pointer to HDF5 file */
+  UNUSED const char *groupName,           /**< Name of group in HDF file */
+  UNUSED REAL8 ref_point                  /**< Point at which to evaluate */
+  )
+{
+  #ifndef LAL_HDF5_ENABLED
+  XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
+  #else
+  LALH5File *curr_group = NULL;
+  gsl_vector *curr_t_vec = NULL;
+  gsl_vector *curr_y_vec = NULL;
+  gsl_interp_accel *acc;
+  gsl_spline *spline;
+  REAL8 ret_val;
+  curr_group = XLALH5GroupOpen(file, groupName);
+  ReadHDF5RealVectorDataset(curr_group, "X", &curr_t_vec);
+  ReadHDF5RealVectorDataset(curr_group, "Y", &curr_y_vec);
+  XLALH5FileClose(curr_group);
+  acc = gsl_interp_accel_alloc();
+  spline = gsl_spline_alloc(gsl_interp_cspline, curr_t_vec->size);
+  gsl_spline_init(spline, curr_t_vec->data, curr_y_vec->data,
+                  curr_t_vec->size);
+  ret_val = gsl_spline_eval(spline, ref_point, acc);
+  gsl_vector_free(curr_t_vec);
+  gsl_vector_free(curr_y_vec);
+  gsl_spline_free (spline);
+  gsl_interp_accel_free (acc);
+  return ret_val;
+  #endif
+}
+
 /* Everything needs to be declared as unused in case HDF is not enabled. */
 UNUSED static UINT4 XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(
   UNUSED REAL8 *S1x,           /**< [out] Dimensionless spin1x in LAL frame */
@@ -65,6 +165,8 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(
   UNUSED REAL8 *S2x,           /**< [out] Dimensionless spin2x in LAL frame */
   UNUSED REAL8 *S2y,           /**< [out] Dimensionless spin2y in LAL frame */
   UNUSED REAL8 *S2z,           /**< [out] Dimensionless spin2z in LAL frame */
+  UNUSED REAL8 fRef,           /**< Reference frequency */
+  UNUSED REAL8 mTot,           /**< Total mass */
   UNUSED LALH5File* file       /**< Pointer to HDF5 file */
 )
 {
@@ -72,21 +174,91 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(
   XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
   #else
   REAL8 nrSpin1x, nrSpin1y, nrSpin1z, nrSpin2x, nrSpin2y, nrSpin2z;
-  REAL8 ln_hat_x, ln_hat_y, ln_hat_z, n_hat_x, n_hat_y, n_hat_z;
-  XLALH5FileQueryScalarAttributeValue(&nrSpin1x, file, "spin1x");
-  XLALH5FileQueryScalarAttributeValue(&nrSpin1y, file, "spin1y");
-  XLALH5FileQueryScalarAttributeValue(&nrSpin1z, file, "spin1z");
-  XLALH5FileQueryScalarAttributeValue(&nrSpin2x, file, "spin2x");
-  XLALH5FileQueryScalarAttributeValue(&nrSpin2y, file, "spin2y");
-  XLALH5FileQueryScalarAttributeValue(&nrSpin2z, file, "spin2z");
+  REAL8 ln_hat_x, ln_hat_y, ln_hat_z, n_hat_x, n_hat_y, n_hat_z, n_norm;
+  REAL8 pos1x, pos1y, pos1z, pos2x, pos2y, pos2z;
+  REAL8 ref_time;
+  INT8 nr_file_format;
+  /* We'll work by always using mTot = 1 */
+  fRef = fRef * mTot;
 
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_x , file, "LNhatx");
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_y , file, "LNhaty");
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_z , file, "LNhatz");
+  XLALH5FileQueryScalarAttributeValue(&nr_file_format, file, "Format");
+  if ((nr_file_format < 2) && (fRef > 0))
+  {
+    /* Supplying a fRef > 0 indicates that the user actually wants to use
+     * fRef. If this is not possible, because the file format is < 2, then
+     * the code will fail. */
+    XLAL_ERROR(XLAL_EINVAL, "This NR file is format 1. Only formats 2 and above support the use of reference frequency. For formats < 2 give the reference frequency as 0 or -1 to indicate that the start of the waveform should be used as the reference.");
+  }
 
-  XLALH5FileQueryScalarAttributeValue(&n_hat_x , file, "nhatx");
-  XLALH5FileQueryScalarAttributeValue(&n_hat_y , file, "nhaty");
-  XLALH5FileQueryScalarAttributeValue(&n_hat_z , file, "nhatz");
+  /* Check if fRef is possible given inputs */
+  fRef = XLALSimInspiralNRWaveformCheckFRef(file, fRef);
+
+  if (fRef <= 0)
+  {
+    XLALH5FileQueryScalarAttributeValue(&nrSpin1x, file, "spin1x");
+    XLALH5FileQueryScalarAttributeValue(&nrSpin1y, file, "spin1y");
+    XLALH5FileQueryScalarAttributeValue(&nrSpin1z, file, "spin1z");
+    XLALH5FileQueryScalarAttributeValue(&nrSpin2x, file, "spin2x");
+    XLALH5FileQueryScalarAttributeValue(&nrSpin2y, file, "spin2y");
+    XLALH5FileQueryScalarAttributeValue(&nrSpin2z, file, "spin2z");
+
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_x , file, "LNhatx");
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_y , file, "LNhaty");
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_z , file, "LNhatz");
+
+    XLALH5FileQueryScalarAttributeValue(&n_hat_x , file, "nhatx");
+    XLALH5FileQueryScalarAttributeValue(&n_hat_y , file, "nhaty");
+    XLALH5FileQueryScalarAttributeValue(&n_hat_z , file, "nhatz");
+  }
+  else
+  {
+    /* This will be real slow if done many times!
+     * One speed issue is we create the spline for *all* points, but only
+     * evaluate at a single point. */
+
+    /* First interpolate between time and freq to get a reference time */
+    ref_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(file, fRef);
+
+    /* Now use ref_time to get spins, LN and nhat */
+    nrSpin1x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin1x-vs-time", ref_time);
+    nrSpin1y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin1y-vs-time", ref_time);
+    nrSpin1z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin1z-vs-time", ref_time);
+    nrSpin2x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin2x-vs-time", ref_time);
+    nrSpin2y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin2y-vs-time", ref_time);
+    nrSpin2z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "spin2z-vs-time", ref_time);
+    ln_hat_x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "LNhatx-vs-time", ref_time);
+    ln_hat_y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "LNhaty-vs-time", ref_time);
+    ln_hat_z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "LNhatz-vs-time", ref_time);
+    /* Would have been easier if we could store n_hat directly!! */
+    pos1x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position1x-vs-time", ref_time);
+    pos1y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position1y-vs-time", ref_time);
+    pos1z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position1z-vs-time", ref_time);
+    pos2x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position2x-vs-time", ref_time);
+    pos2y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position2y-vs-time", ref_time);
+    pos2z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (file, "position2z-vs-time", ref_time);
+    n_hat_x = pos2x - pos1x;
+    n_hat_y = pos2y - pos1y;
+    n_hat_z = pos2z - pos1z;
+    n_norm = sqrt(n_hat_x*n_hat_x + n_hat_y*n_hat_y + n_hat_z*n_hat_z);
+    n_hat_x = n_hat_x / n_norm;
+    n_hat_y = n_hat_y / n_norm;
+    n_hat_z = n_hat_z / n_norm;
+  }
 
   *S1x = nrSpin1x * n_hat_x + nrSpin1y * n_hat_y + nrSpin1z * n_hat_z;
   *S1y = nrSpin1x * (-ln_hat_z * n_hat_y + ln_hat_y * n_hat_z)
@@ -128,6 +300,7 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetDataFromHDF5File(
 
   ReadHDF5RealVectorDataset(group, "X", &knotsVector);
   ReadHDF5RealVectorDataset(group, "Y", &dataVector);
+  XLALH5FileClose(group);
 
   *output = XLALCreateREAL8Vector(length);
 
@@ -141,6 +314,16 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetDataFromHDF5File(
   for (idx = 0; idx < length; idx++)
   {
     massTime = (startTime + idx*deltaT) / (totalMass * LAL_MTSUN_SI);
+    /* This if statement is used to catch the case where massTime at idx=0
+     * ends up at double precision smaller than the first point in the
+     * interpolation. In this case set it back to exactly the first point.
+     * Sanity checking that we are not trying to use data below the
+     * interpolation range is done elsewhere.
+     */
+    if ((idx == 0) && (massTime < knotsVector->data[0]))
+    {
+      massTime = knotsVector->data[0];
+    }
     (*output)->data[idx] = gsl_spline_eval(spline, massTime, acc);
   }
 
@@ -160,7 +343,8 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(
   UNUSED REAL8 *salpha,           /**< Returned sine of the polarisation angle */
   UNUSED LALH5File* filepointer,  /**< Pointer to NR HDF5 file */
   UNUSED const REAL8 inclination, /**< Inclination of source */
-  UNUSED const REAL8 phi_ref      /**< Orbital reference phase*/
+  UNUSED const REAL8 phi_ref,     /**< Orbital reference phase*/
+  UNUSED REAL8 fRef         /**< Reference frequency */
   )
 {
   #ifndef LAL_HDF5_ENABLED
@@ -173,8 +357,9 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(
 
   /* Attribute declarations go in here */
   /* Declarations */
-  REAL8 orb_phase, ln_hat_x, ln_hat_y, ln_hat_z, ln_hat_norm;
+  REAL8 orb_phase, ln_hat_x, ln_hat_y, ln_hat_z, ln_hat_norm, ref_time;
   REAL8 n_hat_x, n_hat_y, n_hat_z, n_hat_norm;
+  REAL8 pos1x, pos1y, pos1z, pos2x, pos2y, pos2z;
   REAL8 corb_phase, sorb_phase, sinclination, cinclination;
   REAL8 ln_cross_n_x, ln_cross_n_y, ln_cross_n_z;
   REAL8 z_wave_x, z_wave_y, z_wave_z;
@@ -183,19 +368,55 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(
   REAL8 n_dot_theta, ln_cross_n_dot_theta, n_dot_psi, ln_cross_n_dot_psi;
   REAL8 y_val;
 
+  fRef = XLALSimInspiralNRWaveformCheckFRef(filepointer, fRef);
+
   /* Following section IV of DCC-T1600045
    * Step 1: Define Phi = phiref/2 ... I'm ignoring this, I think it is wrong
    */
-
   orb_phase = phi_ref;
 
   /* Step 2: Compute Zref
    * 2.1: Compute LN_hat from file. LN_hat = direction of orbital ang. mom.
+   * 2.2: Compute n_hat from file.
+   * n_hat = direction from object 2 to object 1
    */
 
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_x , filepointer, "LNhatx");
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_y , filepointer, "LNhaty");
-  XLALH5FileQueryScalarAttributeValue(&ln_hat_z , filepointer, "LNhatz");
+  if (fRef > 0)
+  {
+    ref_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(filepointer,
+                                                              fRef);
+    ln_hat_x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "LNhatx-vs-time", ref_time);
+    ln_hat_y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "LNhaty-vs-time", ref_time);
+    ln_hat_z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "LNhatz-vs-time", ref_time);
+    /* Would have been easier if we could store n_hat directly!! */
+    pos1x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position1x-vs-time", ref_time);
+    pos1y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position1y-vs-time", ref_time);
+    pos1z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position1z-vs-time", ref_time);
+    pos2x = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position2x-vs-time", ref_time);
+    pos2y = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position2y-vs-time", ref_time);
+    pos2z = XLALSimInspiralNRWaveformGetInterpValueFromGroupAtPoint
+        (filepointer, "position2z-vs-time", ref_time);
+    n_hat_x = pos2x - pos1x;
+    n_hat_y = pos2y - pos1y;
+    n_hat_z = pos2z - pos1z;
+  }
+  else
+  {
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_x , filepointer, "LNhatx");
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_y , filepointer, "LNhaty");
+    XLALH5FileQueryScalarAttributeValue(&ln_hat_z , filepointer, "LNhatz");
+    XLALH5FileQueryScalarAttributeValue(&n_hat_x , filepointer, "nhatx");
+    XLALH5FileQueryScalarAttributeValue(&n_hat_y , filepointer, "nhaty");
+    XLALH5FileQueryScalarAttributeValue(&n_hat_z , filepointer, "nhatz");
+  }
 
   ln_hat_norm = sqrt(ln_hat_x * ln_hat_x + ln_hat_y * ln_hat_y + ln_hat_z * ln_hat_z);
 
@@ -203,14 +424,6 @@ UNUSED static UINT4 XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(
   ln_hat_y = ln_hat_y / ln_hat_norm;
   ln_hat_z = ln_hat_z / ln_hat_norm;
 
-  /* 2.2: Compute n_hat from file.
-   * n_hat = direction from object 2 to object 1
-   */
-
-  XLALH5FileQueryScalarAttributeValue(&n_hat_x , filepointer, "nhatx");
-  XLALH5FileQueryScalarAttributeValue(&n_hat_y , filepointer, "nhaty");
-  XLALH5FileQueryScalarAttributeValue(&n_hat_z , filepointer, "nhatz");
-
   n_hat_norm = sqrt(n_hat_x * n_hat_x + n_hat_y * n_hat_y + n_hat_z * n_hat_z);
 
   n_hat_x = n_hat_x / n_hat_norm;
@@ -338,6 +551,8 @@ int XLALSimInspiralNRWaveformGetSpinsFromHDF5File(
   UNUSED REAL8 *S2x,             /**< [out] Dimensionless spin2x in LAL frame */
   UNUSED REAL8 *S2y,             /**< [out] Dimensionless spin2y in LAL frame */
   UNUSED REAL8 *S2z,             /**< [out] Dimensionless spin2z in LAL frame */
+  UNUSED REAL8 fRef,             /**< Reference frequency */
+  UNUSED REAL8 mTot,             /**< Total mass */
   UNUSED const char *NRDataFile  /**< Location of NR HDF file */
 )
 {
@@ -348,11 +563,13 @@ int XLALSimInspiralNRWaveformGetSpinsFromHDF5File(
   file = XLALH5FileOpen(NRDataFile, "r");
   if (file == NULL)
   {
-     XLAL_ERROR(XLAL_EIO, "NR SIMULATION DATA FILE %s NOT FOUND.\n", NRDataFile);
+     XLAL_ERROR(XLAL_EIO, "NR SIMULATION DATA FILE %s NOT FOUND.\n",
+                NRDataFile);
   }
-  XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(S1x, S1y, S1z, S2x, S2y,
-                                                       S2z, file);
-
+  XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(S1x, S1y, S1z, S2x,
+                                                       S2y, S2z, fRef, mTot,
+                                                       file);
+  XLALH5FileClose(file);
   return XLAL_SUCCESS;
   #endif
 }
@@ -376,20 +593,21 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
         UNUSED REAL8 s2x,                      /**< initial value of S2x */
         UNUSED REAL8 s2y,                      /**< initial value of S2y */
         UNUSED REAL8 s2z,                      /**< initial value of S2z */
-        UNUSED const char *NRDataFile          /**< Location of NR HDF file */
+        UNUSED const char *NRDataFile,         /**< Location of NR HDF file */
+        UNUSED LALValue* ModeArray             /**< Container for the ell and m modes to generate. To generate all available modes pass NULL */
         )
 {
   #ifndef LAL_HDF5_ENABLED
   XLAL_ERROR(XLAL_EFAILED, "HDF5 support not enabled");
   #else
   /* Declarations */
-  UINT4 curr_idx;
+  UINT4 curr_idx, nr_file_format;
   INT4 model, modem;
   size_t array_length;
   REAL8 nrEta;
   REAL8 S1x, S1y, S1z, S2x, S2y, S2z;
   REAL8 Mflower, time_start_M, time_start_s, time_end_M, time_end_s;
-  REAL8 chi, est_start_time, curr_h_real, curr_h_imag;
+  REAL8 est_start_time, curr_h_real, curr_h_imag;
   REAL8 theta, psi, calpha, salpha;
   REAL8 distance_scale_fac;
   COMPLEX16 curr_ylm;
@@ -398,8 +616,8 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
 
   /* These keys follow a strict formulation and cannot be longer than 11
    * characters */
-  char amp_key[20];
-  char phase_key[20];
+  char amp_key[30];
+  char phase_key[30];
   gsl_vector *tmpVector=NULL;
   LALH5File *file, *group;
   LIGOTimeGPS tmpEpoch = LIGOTIMEGPSZERO;
@@ -423,7 +641,7 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
   XLALH5FileQueryScalarAttributeValue(&nrEta, file, "eta");
   if (fabs((m1 * m2) / pow((m1 + m2),2.0) - nrEta) > 1E-3)
   {
-     XLAL_ERROR(XLAL_EDOM, "MASSES ARE INCONSISTENT WITH THE MASS RATIO OF THE NR SIMULATION.\n");
+     XLAL_ERROR(XLAL_EDOM, "MASSES (%e and %e) ARE INCONSISTENT WITH THE MASS RATIO OF THE NR SIMULATION (eta=%e).\n", m1, m2, nrEta);
   }
 
   /* Read spin metadata, L_hat, n_hat from HDF5 metadata and make sure
@@ -431,8 +649,15 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
    * recorded in the metadata of the HDF5 file.
    * PS: This assumes that the input spins are in the LAL frame!
    */
+  XLALH5FileQueryScalarAttributeValue(&nr_file_format, file, "Format");
+  if (nr_file_format < 2)
+  {
+    XLALPrintInfo("This NR file is format %d. Only formats 2 and above support the use of reference frequency. For formats < 2 the reference frequency always corresponds to the start of the waveform.", nr_file_format);
+    fRef = -1;
+  }
   XLALSimInspiralNRWaveformGetSpinsFromHDF5FilePointer(&S1x, &S1y, &S1z,
-                                                       &S2x, &S2y, &S2z, file);
+                                                       &S2x, &S2y, &S2z,
+                                                       fRef, m1+m2, file);
 
   if (fabs(S1x - s1x) > 1E-3)
   {
@@ -473,6 +698,7 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
   /* Figure out start time of data */
   group = XLALH5GroupOpen(file, "amp_l2_m2");
   ReadHDF5RealVectorDataset(group, "X", &tmpVector);
+  XLALH5FileClose(group);
   time_start_M = (REAL8)(gsl_vector_get(tmpVector, 0));
   time_end_M = (REAL8)(gsl_vector_get(tmpVector, tmpVector->size - 1));
   gsl_vector_free(tmpVector);
@@ -485,21 +711,46 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
    * FIXME: Is this correct for precessing waveforms?
    */
 
-  chi = XLALSimIMRPhenomBComputeChi(m1, m2, s1z, s2z);
-  est_start_time = XLALSimIMRSEOBNRv2ChirpTimeSingleSpin(m1 * LAL_MSUN_SI,
-                                                m2 * LAL_MSUN_SI, chi, fStart);
-  est_start_time = (-est_start_time) * 1.1;
+  /* We allow fstart to be fractionally lower than expected to
+   * try and catch rounding errors
+   */
+  if (fStart * (1 + 1E-5) < Mflower / (m1 + m2))
+  {
+    XLAL_ERROR(XLAL_EDOM, "WAVEFORM IS NOT LONG ENOUGH TO REACH f_low. \
+                fStart = %e, Mflower = %e, Mflower / (m1 + m2)) = %e",
+                fStart, Mflower, Mflower / (m1 + m2));
+  }
+
+  XLALH5FileQueryScalarAttributeValue(&nr_file_format, file, "Format");
+  if (nr_file_format > 1)
+  {
+    if (XLALSimInspiralNRWaveformCheckFRef(file, fStart * (m1+m2)) > 0)
+    {
+      /* Can use Omega array to get start time */
+      est_start_time = XLALSimInspiralNRWaveformGetRefTimeFromRefFreq(file, fStart * (m1+m2)) * (m1 + m2) * LAL_MTSUN_SI;
+    }
+    else
+    {
+      /* This is the potential weird case where Omega-vs-time does not start
+       * at precisely the same time as flower_at_1MSUN. This gap should be
+       * small, so just use the full waveform here.
+       */
+      est_start_time = time_start_s;
+    }
+  }
+  else
+  {
+    /* Fall back on SEOBNR chirp time estimate */
+    XLALSimIMRSEOBNRv4ROMTimeOfFrequency(&est_start_time, fStart, m1 * LAL_MSUN_SI, m2 * LAL_MSUN_SI, s1z, s2z);
+    est_start_time = (-est_start_time) * 1.1;
+  }
+
   if (est_start_time > time_start_s)
   {
     /* Restrict start time of waveform */
     time_start_s = est_start_time;
     time_start_M = time_start_s / ((m1 + m2) * LAL_MTSUN_SI);
   }
-  else if (fStart < Mflower / (m1 + m2) )
-  {
-     XLAL_ERROR(XLAL_EDOM, "WAVEFORM IS NOT LONG ENOUGH TO REACH f_low. %e %e %e",
-                fStart, Mflower, Mflower / (m1 + m2));
-  }
 
   array_length = (UINT4)(ceil( (time_end_s - time_start_s) / deltaT));
 
@@ -507,7 +758,7 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
 
   theta = psi = calpha = salpha = 0.;
   XLALSimInspiralNRWaveformGetRotationAnglesFromH5File(&theta, &psi, &calpha,
-                       &salpha, file, inclination, phiRef);
+                       &salpha, file, inclination, phiRef, fRef*(m1+m2));
 
   /* Create the return time series, use arbitrary epoch here. We set this
    * properly later. */
@@ -532,19 +783,44 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
   distance_scale_fac = (m1 + m2) * LAL_MRSUN_SI / r;
 
   /* Generate the waveform */
-  for (model=2; model < 9 ; model++)
+  /* NOTE: We assume that for a given ell mode, all m modes are present */
+  INT4 NRLmax;
+  XLALH5FileQueryScalarAttributeValue(&NRLmax, file, "Lmax");
+
+  if ( ModeArray == NULL )
+  {/* Default behaviour: Generate all modes upto NRLmax */
+    ModeArray = XLALSimInspiralCreateModeArray();
+    for (int ell=2; ell<=NRLmax; ell++)
+    {
+        XLALSimInspiralModeArrayActivateAllModesAtL(ModeArray, ell);
+    }
+  }
+  /* else Use the ModeArray given */
+
+  for (model=2; model < (NRLmax + 1) ; model++)
   {
     for (modem=-model; modem < (model+1); modem++)
     {
+
+      /* first check if (l,m) mode is 'activated' in the ModeArray */
+      /* if activated then generate the mode, else skip this mode. */
+      if (XLALSimInspiralModeArrayIsModeActive(ModeArray, model, modem) != 1)
+      {
+          XLAL_PRINT_INFO("SKIPPING model = %i modem = %i\n", model, modem);
+          continue;
+      }
+      XLAL_PRINT_INFO("generateing model = %i modem = %i\n", model, modem);
+
+
       snprintf(amp_key, sizeof(amp_key), "amp_l%d_m%d", model, modem);
       snprintf(phase_key, sizeof(phase_key), "phase_l%d_m%d", model, modem);
 
       /* Check that both groups exist */
-      if (XLALH5CheckGroupExists(file, amp_key) == 0)
+      if (XLALH5FileCheckGroupExists(file, amp_key) == 0)
       {
         continue;
       }
-      if (XLALH5CheckGroupExists(file, phase_key) == 0)
+      if (XLALH5FileCheckGroupExists(file, phase_key) == 0)
       {
         continue;
       }
@@ -580,8 +856,9 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
 
   }
 
- /* Correct for the "alpha" angle as given in T1600045 to translate
-  * from the NR wave frame to LAL wave-frame
+ /* Correct for the "alpha" angle as given in T1500606 or arxiv:1703.01076
+  * to translate from the NR wave frame to LAL wave-frame.
+  *
   * Helper time series needed.
   */
 
@@ -599,6 +876,7 @@ int XLALSimInspiralNRWaveformGetHplusHcross(
   XLALDestroyREAL8TimeSeries(hplus_corr);
   XLALDestroyREAL8TimeSeries(hcross_corr);
   XLALH5FileClose(file);
+  XLALDestroyValue(ModeArray);
 
   return XLAL_SUCCESS;
   #endif
