@@ -55,6 +55,19 @@
 #define omp ignore
 #endif
 
+/* Macro functions to rotate the components of a vector about an axis */
+#define ROTATEZ(angle, vx, vy, vz)\
+tmp1 = vx*cos(angle) - vy*sin(angle);\
+tmp2 = vx*sin(angle) + vy*cos(angle);\
+vx = tmp1;\
+vy = tmp2
+
+#define ROTATEY(angle, vx, vy, vz)\
+tmp1 = vx*cos(angle) + vz*sin(angle);\
+tmp2 = - vx*sin(angle) + vz*cos(angle);\
+vx = tmp1;\
+vz = tmp2
+
 const double sqrt_6 = 2.44948974278317788;
 
 /* ************************************* Implementation ****************************************/
@@ -80,12 +93,23 @@ const double sqrt_6 = 2.44948974278317788;
  * Each IMRPhenomP version inherits its range of validity
  * over the parameter space from the respective aligned-spin waveform.
  *
- * @attention A time-domain implementation of IMRPhenomPv2 is available in XLALChooseTDWaveform(). 
+ * @attention A time-domain implementation of IMRPhenomPv2 is available in XLALChooseTDWaveform().
  * This is based on a straight-forward inverse Fourier transformation via XLALSimInspiralTDfromFD(),
- * but it was not included in the IMRPhenomPv2 review. Use it at your own risk. 
+ * but it was not included in the IMRPhenomPv2 review. Use it at your own risk.
  */
 
+static REAL8 atan2tol(REAL8 a, REAL8 b, REAL8 tol)
+{
+  REAL8 c;
+  if (fabs(a) < tol && fabs(b) < tol)
+    c = 0.;
+  else
+    c = atan2(a, b);
+  return c;
+}
+
 /**
+ * Deprecated : used the old convention (view frame for the spins)
  * Function to map LAL parameters
  * (masses, 6 spin components and Lhat at f_ref)
  * into IMRPhenomP intrinsic parameters
@@ -95,7 +119,7 @@ const double sqrt_6 = 2.44948974278317788;
  *
  * See Fig. 1. in arxiv:1408.1810 for a diagram of the angles.
  */
-int XLALSimIMRPhenomPCalculateModelParameters(
+int XLALSimIMRPhenomPCalculateModelParametersOld(
     REAL8 *chi1_l,                  /**< [out] Dimensionless aligned spin on companion 1 */
     REAL8 *chi2_l,                  /**< [out] Dimensionless aligned spin on companion 2 */
     REAL8 *chip,                    /**< [out] Effective spin in the orbital plane */
@@ -193,10 +217,7 @@ int XLALSimIMRPhenomPCalculateModelParameters(
   }
 
   REAL8 phiJ; // We only use this angle internally since it is degenerate with alpha0.
-  if (Jx0 < DBL_MIN && Jy0 < DBL_MIN)
-    phiJ = 0;
-  else
-    phiJ = atan2(Jy0, Jx0); /* Angle of J0 in the plane of the sky */
+  phiJ = atan2tol(Jy0, Jx0, MAX_TOL_ATAN); /* Angle of J0 in the plane of the sky */
     /* Note: Compared to the similar code in SpinTaylorF2 we have defined phiJ as the angle between the positive
     (rather than the negative) x-axis and the projection of J0, since this is a more natural definition of the angle.
     We have also renamed the angle from psiJ to phiJ. */
@@ -211,14 +232,218 @@ int XLALSimIMRPhenomPCalculateModelParameters(
   */
   const REAL8 rotLx = -lnhatx*cos(*thetaJ)*cos(phiJ) - lnhaty*cos(*thetaJ)*sin(phiJ) + lnhatz*sin(*thetaJ);
   const REAL8 rotLy = lnhatx*sin(phiJ) - lnhaty*cos(phiJ);
-  if (rotLx == 0.0 && rotLy == 0.0)
-    *alpha0 = 0.0;
-  else
-    *alpha0 = atan2(rotLy, rotLx);
+  *alpha0 = atan2tol(rotLy, rotLx, MAX_TOL_ATAN);
 
   return XLAL_SUCCESS;
 }
 
+
+
+/**
+ * Function to map LAL parameters
+ * (masses, 6 spin components, phiRef and inclination at f_ref)
+ * (assumed to be in the source frame
+ *  where LN points in the z direction
+ *  i.e. lnhat = (0,0,1)
+ *  and the separation vector n is in the x direction
+ *  and the spherical angles of the line of sight N are (incl,Pi/2-phiRef))
+ * into IMRPhenomP intrinsic parameters
+ * (chi1_l, chi2_l, chip, thetaJN, alpha0 and phi_aligned).
+ *
+ * All input masses and frequencies should be in SI units.
+ *
+ * See Fig. 1. in arxiv:1408.1810 for a diagram of the angles.
+ */
+int XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame(
+    REAL8 *chi1_l,                  /**< [out] Dimensionless aligned spin on companion 1 */
+    REAL8 *chi2_l,                  /**< [out] Dimensionless aligned spin on companion 2 */
+    REAL8 *chip,                    /**< [out] Effective spin in the orbital plane */
+    REAL8 *thetaJN,                  /**< [out] Angle between J0 and line of sight (z-direction) */
+    REAL8 *alpha0,                  /**< [out] Initial value of alpha angle (azimuthal precession angle) */
+    REAL8 *phi_aligned,                  /**< [out] Initial phase to feed the underlying aligned-spin model */
+    REAL8 *zeta_polariz,                  /**< [out] Angle to rotate the polarizations */
+    const REAL8 m1_SI,              /**< Mass of companion 1 (kg) */
+    const REAL8 m2_SI,              /**< Mass of companion 2 (kg) */
+    const REAL8 f_ref,              /**< Reference GW frequency (Hz) */
+    const REAL8 phiRef,              /**< Reference phase */
+    const REAL8 incl,              /**< Inclination : angle between LN and the line of sight */
+    const REAL8 s1x,                /**< Initial value of s1x: dimensionless spin of BH 1 */
+    const REAL8 s1y,                /**< Initial value of s1y: dimensionless spin of BH 1 */
+    const REAL8 s1z,                /**< Initial value of s1z: dimensionless spin of BH 1 */
+    const REAL8 s2x,                /**< Initial value of s2x: dimensionless spin of BH 2 */
+    const REAL8 s2y,                /**< Initial value of s2y: dimensionless spin of BH 2 */
+    const REAL8 s2z,                /**< Initial value of s2z: dimensionless spin of BH 2 */
+    IMRPhenomP_version_type IMRPhenomP_version /**< IMRPhenomP(v1) uses IMRPhenomC, IMRPhenomPv2 uses IMRPhenomD */
+)
+{
+  // Note that the angle phiJ defined below and alpha0 are degenerate. Therefore we do not output phiJ.
+
+  /* Check arguments for sanity */
+  XLAL_CHECK(chi1_l != NULL, XLAL_EFAULT);
+  XLAL_CHECK(chi2_l != NULL, XLAL_EFAULT);
+  XLAL_CHECK(chip != NULL, XLAL_EFAULT);
+  XLAL_CHECK(thetaJN != NULL, XLAL_EFAULT);
+  XLAL_CHECK(alpha0 != NULL, XLAL_EFAULT);
+  XLAL_CHECK(phi_aligned != NULL, XLAL_EFAULT);
+
+  XLAL_CHECK(f_ref > 0, XLAL_EDOM, "Reference frequency must be positive.\n");
+  XLAL_CHECK(m1_SI > 0, XLAL_EDOM, "m1 must be positive.\n");
+  XLAL_CHECK(m2_SI > 0, XLAL_EDOM, "m2 must be positive.\n");
+  XLAL_CHECK(fabs(s1x*s1x + s1y*s1y + s1z*s1z) <= 1.0, XLAL_EDOM, "|S1/m1^2| must be <= 1.\n");
+  XLAL_CHECK(fabs(s2x*s2x + s2y*s2y + s2z*s2z) <= 1.0, XLAL_EDOM, "|S2/m2^2| must be <= 1.\n");
+
+  const REAL8 m1 = m1_SI / LAL_MSUN_SI;   /* Masses in solar masses */
+  const REAL8 m2 = m2_SI / LAL_MSUN_SI;
+  const REAL8 M = m1+m2;
+  const REAL8 m1_2 = m1*m1;
+  const REAL8 m2_2 = m2*m2;
+  const REAL8 eta = m1 * m2 / (M*M);    /* Symmetric mass-ratio */
+
+  /* From the components in the source frame, we can easily determine
+   chi1_l, chi2_l, chip and phi_aligned, which we need to return.
+   We also compute the spherical angles of J,
+   which we need to transform to the J frame*/
+
+  /* Aligned spins */
+  *chi1_l = s1z; /* Dimensionless aligned spin on BH 1 */
+  *chi2_l = s2z; /* Dimensionless aligned spin on BH 2 */
+
+  /* Magnitude of the spin projections in the orbital plane */
+  const REAL8 S1_perp = m1_2*sqrt(s1x*s1x + s1y*s1y);
+  const REAL8 S2_perp = m2_2*sqrt(s2x*s2x + s2y*s2y);
+  /* From this we can compute chip*/
+  const REAL8 A1 = 2 + (3*m2) / (2*m1);
+  const REAL8 A2 = 2 + (3*m1) / (2*m2);
+  const REAL8 ASp1 = A1*S1_perp;
+  const REAL8 ASp2 = A2*S2_perp;
+  const REAL8 num = (ASp2 > ASp1) ? ASp2 : ASp1;
+  const REAL8 den = (m2 > m1) ? A2*m2_2 : A1*m1_2;
+  *chip = num / den; /*  chip = max(A1 Sp1, A2 Sp2) / (A_i m_i^2) for i index of larger BH (See Eqn. 32 in technical document) */
+
+  /* Compute L, J0 and orientation angles */
+  const REAL8 m_sec = M * LAL_MTSUN_SI;   /* Total mass in seconds */
+  const REAL8 piM = LAL_PI * m_sec;
+  const REAL8 v_ref = cbrt(piM * f_ref);
+
+  REAL8 L0 = 0.0;
+  switch (IMRPhenomP_version) {
+    case IMRPhenomPv1_V:
+      L0 = M*M * L2PNR_v1(v_ref, eta); /* Use 2PN approximation for L. */
+      break;
+    case IMRPhenomPv2_V:
+      L0 = M*M * L2PNR(v_ref, eta);   /* Use 2PN approximation for L. */
+      break;
+    default:
+      XLAL_ERROR( XLAL_EINVAL, "Unknown IMRPhenomP version!\nAt present only v1 and v2 are available." );
+      break;
+    }
+  // Below, _sf indicates source frame components. We will also use _Jf for J frame components
+  const REAL8 J0x_sf = m1_2*s1x + m2_2*s2x;
+  const REAL8 J0y_sf = m1_2*s1y + m2_2*s2y;
+  const REAL8 J0z_sf = L0 + m1_2*s1z + m2_2*s2z;
+  const REAL8 J0 = sqrt(J0x_sf*J0x_sf + J0y_sf*J0y_sf + J0z_sf*J0z_sf);
+
+  /* Compute thetaJ, the angle between J0 and LN (z-direction) */
+  REAL8 thetaJ_sf;
+  if (J0 < 1e-10) {
+    XLAL_PRINT_WARNING("Warning: |J0| < 1e-10. Setting thetaJ = 0.\n");
+    thetaJ_sf = 0;
+  } else {
+    thetaJ_sf = acos(J0z_sf / J0);
+  }
+
+  REAL8 phiJ_sf;
+  if (fabs(J0x_sf) < MAX_TOL_ATAN && fabs(J0y_sf) < MAX_TOL_ATAN)
+    phiJ_sf = LAL_PI/2. - phiRef; // aligned spin limit
+  else
+    phiJ_sf = atan2(J0y_sf, J0x_sf); /* azimuthal angle of J0 in the source frame */
+
+  *phi_aligned = - phiJ_sf;
+
+  /* We now have to rotate to the "J frame" where we can easily
+   compute alpha0, the azimuthal angle of LN,
+   as well as thetaJ, the angle between J and N.
+   The J frame is defined imposing that J points in the z direction
+   and the line of sight N is in the xz plane (with positive projection along x).
+   The components of any vector in the (new) J frame are obtained from those
+   in the (old) source frame by multiplying by RZ[kappa].RY[-thetaJ].RZ[-phiJ]
+   where kappa will be determined by rotating N with RY[-thetaJ].RZ[-phiJ]
+   (which brings J to the z axis) and taking the opposite of azimuthal angle of the rotated N.
+   */
+  REAL8 tmp1,tmp2;
+  // First we determine kappa
+  // in the source frame, the components of N are given in Eq (35c) of T1500606-v6
+  REAL8 Nx_sf = sin(incl)*cos(LAL_PI/2. - phiRef);
+  REAL8 Ny_sf = sin(incl)*sin(LAL_PI/2. - phiRef);
+  REAL8 Nz_sf = cos(incl);
+  REAL8 tmp_x = Nx_sf;
+  REAL8 tmp_y = Ny_sf;
+  REAL8 tmp_z = Nz_sf;
+  ROTATEZ(-phiJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEY(-thetaJ_sf, tmp_x, tmp_y, tmp_z);
+  REAL8 kappa;
+  kappa = - atan2tol(tmp_y,tmp_x, MAX_TOL_ATAN);
+
+  // Then we determine alpha0, by rotating LN
+  tmp_x = 0.;
+  tmp_y = 0.;
+  tmp_z = 1.; // in the source frame, LN=(0,0,1)
+  ROTATEZ(-phiJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEY(-thetaJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEZ(kappa, tmp_x, tmp_y, tmp_z);
+  if (fabs(tmp_x) < MAX_TOL_ATAN && fabs(tmp_y) < MAX_TOL_ATAN)
+    *alpha0 = LAL_PI; //this is the aligned spin case
+  else
+    *alpha0 = atan2(tmp_y,tmp_x);
+
+  // Finally we determine thetaJ, by rotating N
+  tmp_x = Nx_sf;
+  tmp_y = Ny_sf;
+  tmp_z = Nz_sf;
+  ROTATEZ(-phiJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEY(-thetaJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEZ(kappa, tmp_x, tmp_y, tmp_z);
+  REAL8 Nx_Jf = tmp_x; // let's store those two since we will reuse them later (we don't need the y component)
+  REAL8 Nz_Jf = tmp_z;
+  *thetaJN = acos(Nz_Jf); // No normalization needed, we are dealing with a unit vector
+
+  /* Finally, we need to redefine the polarizations :
+   PhenomP's polarizations are defined following Arun et al (arXiv:0810.5336)
+   i.e. projecting the metric onto the P,Q,N triad defined with P=NxJ/|NxJ| (see (2.6) in there).
+   By contrast, the triad X,Y,N used in LAL
+   ("waveframe" in the nomenclature of T1500606-v6)
+   is defined in e.g. eq (35) of this document
+   (via its components in the source frame; note we use the defautl Omega=Pi/2).
+   Both triads differ from each other by a rotation around N by an angle \zeta
+   and we need to rotate the polarizations accordingly by 2\zeta
+  */
+  REAL8 Xx_sf = -cos(incl)*sin(phiRef);
+  REAL8 Xy_sf = -cos(incl)*cos(phiRef);
+  REAL8 Xz_sf = sin(incl);
+  tmp_x = Xx_sf;
+  tmp_y = Xy_sf;
+  tmp_z = Xz_sf;
+  ROTATEZ(-phiJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEY(-thetaJ_sf, tmp_x, tmp_y, tmp_z);
+  ROTATEZ(kappa, tmp_x, tmp_y, tmp_z);
+  //now the tmp_a are the components of X in the J frame
+  //we need the polar angle of that vector in the P,Q basis of Arun et al
+  // P=NxJ/|NxJ| and since we put N in the (pos x)z half plane of the J frame
+  REAL8 PArunx_Jf = 0.;
+  REAL8 PAruny_Jf = -1.;
+  REAL8 PArunz_Jf = 0.;
+  // Q=NxP
+  REAL8 QArunx_Jf = Nz_Jf;
+  REAL8 QAruny_Jf = 0.;
+  REAL8 QArunz_Jf = -Nx_Jf;
+  REAL8 XdotPArun = tmp_x*PArunx_Jf+tmp_y*PAruny_Jf+tmp_z*PArunz_Jf;
+  REAL8 XdotQArun = tmp_x*QArunx_Jf+tmp_y*QAruny_Jf+tmp_z*QArunz_Jf;
+  *zeta_polariz = atan2(XdotQArun , XdotPArun);
+
+  return XLAL_SUCCESS;
+}
+
+
 /**
  * Driver routine to compute the precessing inspiral-merger-ringdown
  * phenomenological waveform IMRPhenomP in the frequency domain.
@@ -226,7 +451,7 @@ int XLALSimIMRPhenomPCalculateModelParameters(
  * Reference:
  * - Hannam et al., arXiv:1308.3271 [gr-qc]
  *
- * \ref XLALSimIMRPhenomPCalculateModelParameters should be called first
+ * \ref XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame should be called first
  * to map LAL parameters into IMRPhenomP intrinsic parameters
  * (chi1_l, chi2_l, chip, thetaJ, alpha0).
  *
@@ -250,10 +475,10 @@ int XLALSimIMRPhenomP(
   const REAL8 f_max,                          /**< End frequency; 0 defaults to ringdown cutoff freq */
   const REAL8 f_ref,                          /**< Reference frequency */
   IMRPhenomP_version_type IMRPhenomP_version, /**< IMRPhenomPv1 uses IMRPhenomC, IMRPhenomPv2 uses IMRPhenomD */
-  const LALSimInspiralTestGRParam *extraParams) /**<linked list containing the extra testing GR parameters */
+  LALDict *extraParams) /**<linked list containing the extra testing GR parameters */
 {
   // See Fig. 1. in arxiv:1408.1810 for diagram of the angles.
-  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParameters
+  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame
   // and alpha0 are degenerate. Therefore phiJ is not passed to this function.
 
   // Use f_min, f_max, deltaF to compute freqs sequence
@@ -281,7 +506,7 @@ int XLALSimIMRPhenomP(
  * Reference:
  * - Hannam et al., arXiv:1308.3271 [gr-qc]
  *
- * \ref XLALSimIMRPhenomPCalculateModelParameters should be called first
+ * \ref XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame should be called first
  * to map LAL parameters into IMRPhenomP intrinsic parameters
  * (chi1_l, chi2_l, chip, thetaJ, alpha0).
  *
@@ -304,10 +529,10 @@ int XLALSimIMRPhenomPFrequencySequence(
   const REAL8 phic,                           /**< Orbital phase at the peak of the underlying non precessing model (rad) */
   const REAL8 f_ref,                          /**< Reference frequency */
   IMRPhenomP_version_type IMRPhenomP_version, /**< IMRPhenomPv1 uses IMRPhenomC, IMRPhenomPv2 uses IMRPhenomD */
-  const LALSimInspiralTestGRParam *extraParams) /**<linked list containing the extra testing GR parameters */
+  LALDict *extraParams) /**<linked list containing the extra testing GR parameters */
 {
   // See Fig. 1. in arxiv:1408.1810 for diagram of the angles.
-  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParameters
+  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame
   // and alpha0 are degenerate. Therefore phiJ is not passed to this function.
 
   // Call the internal core function with deltaF = 0 to indicate that freqs is non-uniformly
@@ -348,7 +573,7 @@ static int PhenomPCore(
    * spacing deltaF. Otherwise, the frequency points are spaced non-uniformly.
    * Then we will use deltaF = 0 to create the frequency series we return. */
   IMRPhenomP_version_type IMRPhenomP_version, /**< IMRPhenomPv1 uses IMRPhenomC, IMRPhenomPv2 uses IMRPhenomD */
-  const LALSimInspiralTestGRParam *extraParams /**<linked list containing the extra testing GR parameters */
+  LALDict *extraParams /**<linked list containing the extra testing GR parameters */
   )
 {
   /* Check inputs for sanity */
@@ -366,7 +591,7 @@ static int PhenomPCore(
   XLAL_CHECK(fabs(chip) <= 1.0, XLAL_EDOM, "In-plane spin chip =%g must be <= 1 in magnitude!\n", chip);
 
   // See Fig. 1. in arxiv:1408.1810 for diagram of the angles.
-  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParameters
+  // Note that the angles phiJ which is calculated internally in XLALSimIMRPhenomPCalculateModelParametersFromSourceFrame
   // and alpha0 are degenerate. Therefore phiJ is not passed to this function.
   /* Phenomenological parameters */
   IMRPhenomDAmplitudeCoefficients *pAmp = NULL;
@@ -378,6 +603,7 @@ static int PhenomPCore(
   REAL8Sequence *freqs = NULL;
   REAL8 *phis=NULL;
   int errcode = XLAL_SUCCESS;
+  LALDict *extraParams_in=extraParams;
 
   // Enforce convention m2 >= m1
   REAL8 chi1_l, chi2_l;
@@ -507,11 +733,16 @@ static int PhenomPCore(
         XLAL_PRINT_WARNING("Warning: final spin magnitude %g > 1. Setting final spin magnitude = 1.", finspin);
         finspin = copysign(1.0, finspin);
       }
-
       // IMRPhenomD assumes that m1 >= m2.
       pAmp = ComputeIMRPhenomDAmplitudeCoefficients(eta, chi2_l, chi1_l, finspin);
       pPhi = ComputeIMRPhenomDPhaseCoefficients(eta, chi2_l, chi1_l, finspin, extraParams);
-      XLALSimInspiralTaylorF2AlignedPhasing(&pn, m1, m2, chi1_l, chi2_l, 1.0, 1.0, LAL_SIM_INSPIRAL_SPIN_ORDER_35PN, extraParams);
+      if (extraParams==NULL)
+      {
+              extraParams=XLALCreateDict();
+      }
+      XLALSimInspiralWaveformParamsInsertPNSpinOrder(extraParams, LAL_SIM_INSPIRAL_SPIN_ORDER_35PN);
+      XLALSimInspiralTaylorF2AlignedPhasing(&pn, m1, m2, chi1_l, chi2_l, extraParams);
+
       if (!pAmp || !pPhi || !pn) {
         errcode = XLAL_EFUNC;
         goto cleanup;
@@ -643,7 +874,6 @@ static int PhenomPCore(
     errcode = XLAL_ENOMEM;
     goto cleanup;
   }
-  REAL8 phasing = 0;
 
   AmpInsPrefactors amp_prefactors;
   PhiInsPrefactors phi_prefactors;
@@ -664,6 +894,7 @@ static int PhenomPCore(
   for (UINT4 i=0; i<L_fCut; i++) { // loop over frequency points in sequence
     COMPLEX16 hp_val = 0.0;
     COMPLEX16 hc_val = 0.0;
+    REAL8 phasing = 0;
     double f = freqs->data[i];
     int j = i + offset; // shift index for frequency series if needed
 
@@ -711,6 +942,12 @@ static int PhenomPCore(
     goto cleanup;
   }
 
+  if (L_fCut<=5){ // prevent spline interpolation failing in phase correction below
+    XLALPrintError("XLAL Error - %s: PhenomP waveform is too short: L_fcut is too small.", __func__);
+    errcode = XLAL_EDOM;
+    goto cleanup;
+   }
+
   /* Time correction is t(f_final) = 1/(2pi) dphi/df (f_final) */
   REAL8 t_corr = gsl_spline_eval_deriv(phiI, f_final, acc) / (2*LAL_PI);
   /* Now correct phase */
@@ -732,13 +969,21 @@ static int PhenomPCore(
   if(pPhi) XLALFree(pPhi);
   if(pn) XLALFree(pn);
 
+  /* If extraParams was allocated in this function and not passed in
+   * we need to free it to prevent a leak */
+  if(extraParams && !extraParams_in) XLALDestroyDict(extraParams);
+
   if(freqs) XLALDestroyREAL8Sequence(freqs);
 
   if( errcode != XLAL_SUCCESS ) {
-    if(*hptilde)
+    if(*hptilde) {
       XLALDestroyCOMPLEX16FrequencySeries(*hptilde);
-    if(*hctilde)
+      *hptilde=NULL;
+    }
+    if(*hctilde) {
       XLALDestroyCOMPLEX16FrequencySeries(*hctilde);
+      *hctilde=NULL;
+    }
     XLAL_ERROR(errcode);
   }
   else {
@@ -1207,7 +1452,7 @@ static REAL8 FinalSpinIMRPhenomD_all_in_plane_spin_on_larger_BH(
   else {
     q_factor = m2/M;
     af_parallel = FinalSpin0815(eta, chi2_l, chi1_l);
-  }  
+  }
 
   REAL8 Sperp = chip * q_factor*q_factor;
   REAL8 af = copysign(1.0, af_parallel) * sqrt(Sperp*Sperp + af_parallel*af_parallel);
@@ -1305,7 +1550,7 @@ UNUSED static BBHPhenomCParams *ComputeIMRPhenomCParamsRDmod(
   const REAL8 m2,   /**< Mass of companion 2 (solar masses) */
   const REAL8 chi,  /**< Reduced aligned spin of the binary chi = (m1*chi1 + m2*chi2)/M */
   const REAL8 chip, /**< Dimensionless spin in the orbital plane */
-  const LALSimInspiralTestGRParam *extraParams) /**< linked list containing the extra testing GR parameters */
+  LALDict *extraParams) /**< linked list containing the extra testing GR parameters */
 {
 
   BBHPhenomCParams *p = NULL;
@@ -1383,4 +1628,3 @@ static void nudge(REAL8 *x, REAL8 X, REAL8 epsilon) {
       *x = X;
   }
 }
-
