@@ -371,7 +371,6 @@ static int SEOBNRROMdataDS_Init(SEOBNRROMdataDS *romdata, const char dir[]) {
     return (XLAL_FAILURE);
   }
 
-  gsl_set_error_handler(&err_handler);
   (romdata)->cvec_amp = gsl_vector_alloc(N*nk_amp);
   (romdata)->cvec_phi = gsl_vector_alloc(N*nk_phi);
   (romdata)->Bamp = gsl_matrix_alloc(nk_amp, nk_amp);
@@ -492,7 +491,7 @@ static int SEOBNRv1ROMDoubleSpinCore(
 
   // Enforce allowed geometric frequency range
   if (fLow_geom < Mf_ROM_min)
-    XLAL_ERROR(XLAL_EDOM, "Starting frequency Mflow=%g is smaller than lowest frequency in ROM Mf=%g. Starting at lowest frequency in ROM.\n", fLow_geom, Mf_ROM_min);
+    XLAL_ERROR(XLAL_EDOM, "Starting frequency Mflow=%g is smaller than lowest frequency in ROM Mf=%g.\n", fLow_geom, Mf_ROM_min);
   if (fHigh_geom == 0)
     fHigh_geom = Mf_ROM_max;
   else if (fHigh_geom > Mf_ROM_max) {
@@ -637,7 +636,7 @@ static int SEOBNRv1ROMDoubleSpinCore(
     pdata[j] =      pcoef * htilde;
     cdata[j] = -I * ccoef * htilde;
   }
-  
+
   /* Correct phasing so we coalesce at t=0 (with the definition of the epoch=-1/deltaF above) */
 
   // Get SEOBNRv1 ringdown frequency for 22 mode
