@@ -33,6 +33,7 @@
 #include <lal/LALSimInspiral.h>
 #include <lal/Units.h>
 #include <lal/XLALError.h>
+#include <lal/AVFactories.h>
 #include "LALSimInspiralPNCoefficients.c"
 
 #ifndef _OPENMP
@@ -84,18 +85,66 @@ int XLALSimInspiralTaylorF2AlignedPhasing(
     return XLAL_SUCCESS;
 }
 
+int XLALSimInspiralTaylorF2AlignedPhasingArray(
+        REAL8Vector **phasingvals, /**< phasing coefficients (output) */
+        REAL8Vector mass1, /**< Masses of heavier bodies */
+        REAL8Vector mass2, /**< Masses of lighter bodies */
+        REAL8Vector chi1, /**< Aligned spin of body 1 */
+        REAL8Vector chi2, /**< Aligned spin of body 2 */
+        REAL8Vector lambda1, /**< Tidal deformation of body 1 */
+        REAL8Vector lambda2, /**< Tidal deformation of body 2 */
+        REAL8Vector dquadmon1, /**< Self-spin deformation of body 1 */
+        REAL8Vector dquadmon2 /**< Self-spin deformation of body 2 */
+        )
+{
+    UINT4 idx, jdx;
+    UINT4 pnmaxnum = PN_PHASING_SERIES_MAX_ORDER + 1;
+    LALDict *a=NULL;
+    a=XLALCreateDict();
+
+    PNPhasingSeries *curr_phasing=NULL;
+    *phasingvals = XLALCreateREAL8Vector(mass1.length * pnmaxnum * 3); 
+    REAL8Vector* pv = *phasingvals;
+
+    for (idx=0; idx < mass1.length; idx++)
+    {
+        XLALSimInspiralWaveformParamsInsertdQuadMon1(a, dquadmon1.data[idx]);
+        XLALSimInspiralWaveformParamsInsertdQuadMon2(a, dquadmon2.data[idx]);
+        XLALSimInspiralWaveformParamsInsertTidalLambda1(a, lambda1.data[idx]);
+        XLALSimInspiralWaveformParamsInsertTidalLambda2(a, lambda2.data[idx]);
+
+        XLALSimInspiralTaylorF2AlignedPhasing
+            (&curr_phasing, mass1.data[idx], mass2.data[idx], chi1.data[idx],
+             chi2.data[idx], a);
+        for (jdx=0; jdx < pnmaxnum; jdx++)
+        {
+            pv->data[jdx*mass1.length + idx] = curr_phasing->v[jdx];
+            pv->data[mass1.length*pnmaxnum + jdx*mass1.length + idx] =
+                curr_phasing->vlogv[jdx];
+            pv->data[mass1.length*pnmaxnum*2 + idx + jdx*mass1.length] =
+                curr_phasing->vlogvsq[jdx];
+        }
+        LALFree(curr_phasing);
+        curr_phasing=NULL;
+    }
+
+    XLALDestroyDict(a);
+
+    return XLAL_SUCCESS;
+}
+
+
 int XLALSimInspiralTaylorF2Core(
         COMPLEX16FrequencySeries **htilde_out, /**< FD waveform */
 	const REAL8Sequence *freqs,            /**< frequency points at which to evaluate the waveform (Hz) */
         const REAL8 phi_ref,                   /**< reference orbital phase (rad) */
         const REAL8 m1_SI,                     /**< mass of companion 1 (kg) */
         const REAL8 m2_SI,                     /**< mass of companion 2 (kg) */
-        const REAL8 S1z,                       /**<  z component of the spin of companion 1 */
-        const REAL8 S2z,                       /**<  z component of the spin of companion 2  */
         const REAL8 f_ref,                     /**< Reference GW frequency (Hz) - if 0 reference point is coalescence */
 	const REAL8 shft,		       /**< time shift to be applied to frequency-domain phase (sec)*/
         const REAL8 r,                         /**< distance of source (m) */
-        LALDict *p /**< Linked list containing the extra testing GR parameters >**/
+        LALDict *p, /**< Linked list containing the extra testing GR parameters >*/
+        PNPhasingSeries *pfaP /**< Phasing coefficients >**/
         )
 {
 
@@ -108,8 +157,6 @@ int XLALSimInspiralTaylorF2Core(
     const REAL8 m_sec = m * LAL_MTSUN_SI;  /* total mass in seconds */
     const REAL8 eta = m1 * m2 / (m * m);
     const REAL8 piM = LAL_PI * m_sec;
-    const REAL8 m1OverM = m1 / m;
-    const REAL8 m2OverM = m2 / m;
     REAL8 amp0;
     size_t i;
     COMPLEX16 *data = NULL;
@@ -129,9 +176,7 @@ int XLALSimInspiralTaylorF2Core(
 	    XLALUnitMultiply(&htilde->sampleUnits, &htilde->sampleUnits, &lalSecondUnit);
     }
 
-    /* phasing coefficients */
-    PNPhasingSeries pfa;
-    XLALSimInspiralPNPhasing_F2(&pfa, m1, m2, S1z, S2z, S1z*S1z, S2z*S2z, S1z*S2z, p);
+    PNPhasingSeries pfa = *pfaP;
 
     REAL8 pfaN = 0.; REAL8 pfa1 = 0.;
     REAL8 pfa2 = 0.; REAL8 pfa3 = 0.; REAL8 pfa4 = 0.;
@@ -145,20 +190,41 @@ int XLALSimInspiralTaylorF2Core(
         case -1:
         case 7:
             pfa7 = pfa.v[7];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 6:
             pfa6 = pfa.v[6];
             pfl6 = pfa.vlogv[6];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 5:
             pfa5 = pfa.v[5];
             pfl5 = pfa.vlogv[5];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 4:
             pfa4 = pfa.v[4];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 3:
             pfa3 = pfa.v[3];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 2:
             pfa2 = pfa.v[2];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 1:
             pfa1 = pfa.v[1];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case 0:
             pfaN = pfa.v[0];
             break;
@@ -194,15 +260,19 @@ int XLALSimInspiralTaylorF2Core(
      */
     REAL8 pft10 = 0.;
     REAL8 pft12 = 0.;
-    REAL8 lambda1=XLALSimInspiralWaveformParamsLookupTidalLambda1(p);
-    REAL8 lambda2=XLALSimInspiralWaveformParamsLookupTidalLambda2(p);
     switch( XLALSimInspiralWaveformParamsLookupPNTidalOrder(p) )
     {
         case LAL_SIM_INSPIRAL_TIDAL_ORDER_ALL:
         case LAL_SIM_INSPIRAL_TIDAL_ORDER_6PN:
-	    pft12 = pfaN * (lambda1*XLALSimInspiralTaylorF2Phasing_12PNTidalCoeff(m1OverM) + lambda2*XLALSimInspiralTaylorF2Phasing_12PNTidalCoeff(m2OverM) );
+	    pft12 = pfa.v[12];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case LAL_SIM_INSPIRAL_TIDAL_ORDER_5PN:
-            pft10 = pfaN * ( lambda1*XLALSimInspiralTaylorF2Phasing_10PNTidalCoeff(m1OverM) + lambda2*XLALSimInspiralTaylorF2Phasing_10PNTidalCoeff(m2OverM) );
+            pft10 = pfa.v[10];
+#if __GNUC__ >= 7
+            __attribute__ ((fallthrough));
+#endif
         case LAL_SIM_INSPIRAL_TIDAL_ORDER_0PN:
             break;
         default:
@@ -321,19 +391,37 @@ int XLALSimInspiralTaylorF2Core(
         {
             case 7:
                 flux += FTa7 * v7;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case 6:
                 flux += (FTa6 + FTl6*logv) * v6;
                 dEnergy += dETa3 * v6;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case 5:
                 flux += FTa5 * v5;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case 4:
                 flux += FTa4 * v4;
                 dEnergy += dETa2 * v4;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case 3:
                 flux += FTa3 * v3;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case 2:
                 flux += FTa2 * v2;
                 dEnergy += dETa1 * v2;
+#if __GNUC__ >= 7
+                __attribute__ ((fallthrough));
+#endif
             case -1: /* Default to no SPA amplitude corrections */
             case 0:
                 flux += 1.;
@@ -441,8 +529,13 @@ int XLALSimInspiralTaylorF2(
     for (i = iStart; i < n; i++) {
         freqs->data[i-iStart] = i * deltaF;
     }
+
+    /* phasing coefficients */
+    PNPhasingSeries pfa;
+    XLALSimInspiralPNPhasing_F2(&pfa, m1, m2, S1z, S2z, S1z*S1z, S2z*S2z, S1z*S2z, p);
+
     ret = XLALSimInspiralTaylorF2Core(&htilde, freqs, phi_ref, m1_SI, m2_SI,
-                                      S1z, S2z, f_ref, shft, r, p);
+                                      f_ref, shft, r, p, &pfa);
 
     XLALDestroyREAL8Sequence(freqs);
 
