@@ -84,6 +84,9 @@ static LALUnit strainSquaredPerHertzUnit = { 0, { 0, 0, 1, 0, 0, 2, 0}, { 0, 0,
 /* prefix for noise psd files provided by LIGO-T1800044 */
 #define T1800044 "LIGO-T1800044-v5-"
 
+/* prefix for noise psd files provided by LIGO-T1800044 */
+#define T1800545 "LIGO-T1800545-v1-"
+
 /**
  * @addtogroup LALSimNoisePSD_c
  * @brief Routines to compute noise power spectral densities for
@@ -1574,6 +1577,139 @@ int XLALSimNoisePSDaLIGOaLIGODesignSensitivityT1800044(
 
 /** @} */
 
+/**
+ * @name Noise PSDs from LIGO-P1800545
+ * @{
+ */
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to aLIGO O3 low 120 Mpc range in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOaLIGOO3LowT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "aLIGO_O3low.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to aLIGO 140 Mpc range in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOaLIGO140MpcT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "aLIGO_140Mpc.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to aLIGO 175 Mpc range (design) in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOaLIGO175MpcT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "aLIGO_175Mpc.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced Virgo 100 Mpc range (O4 intermediate) in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOAdVO4IntermediateT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "AdV_O4intermediate.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced Virgo 120 Mpc range (O4 design) in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOAdVO4T1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "AdV_O4.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced Virgo 65 Mpc range (O3 low) in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOAdVO3LowT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "AdV_O3low.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced KAGRA 128 Mpc range in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOKAGRA128MpcT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "KAGRA_128Mpc.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced KAGRA 25 Mpc range in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOKAGRA25MpcT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "KAGRA_25Mpc.txt");
+}
+
+/**
+ * Returns a frequency series psd with low frequency cutoff flow corresponding
+ * to advanced KAGRA 80 Mpc range in LIGO-P1800545.
+ */
+
+int XLALSimNoisePSDaLIGOKAGRA80MpcT1800545(
+	REAL8FrequencySeries *psd,	/**< frequency series to be computed */
+	double flow 			/**< low frequency cutoff (Hz) */
+)
+{
+	return XLALSimNoisePSDFromFile(psd, flow,
+		T1800545 "KAGRA_80Mpc.txt");
+}
+
+/** @} */
+
 /** @} */
 
 /*
