@@ -25,7 +25,7 @@
 #include <float.h>
 
 #include <lal/Units.h>
-#include <lal/LALAdaptiveRungeKutta4.h>
+#include <lal/LALAdaptiveRungeKuttaIntegrator.h>
 #include <lal/LALConstants.h>
 #include <lal/FindRoot.h>
 #include <lal/SeqFactories.h>
